@@ -72,7 +72,7 @@ our $VERSION = '0.01';
 =head1 EXPORT
 
 	enumerate
-        full_enum
+    full_enum
 	prepare_for_enumeration
 	pre_gen_list
 	gen_list
@@ -159,7 +159,9 @@ sub prepare_for_enumeration {
 }
 
 =head2 pre_gen_list
-        Subroutine to generate the input list for enumeration
+
+Subroutine to generate the input list for enumeration
+
 =cut
 
 sub pre_gen_list {
@@ -196,7 +198,7 @@ sub pre_gen_list {
 }
 
 =head2 gen_list
-	Subroutine to generate the input list for enumeration
+Subroutine to generate the input list for enumeration
 =cut
 
 sub gen_list {
@@ -235,23 +237,28 @@ and calculates 4 scoring component values: radius of gyration, statistical pairw
 potential, implicit solvation potential, and long range H bond potential.
 
 INPUTS
-1) $pdbcode - the 4-character name of the folder to store input and output data
-2) $mot1 - an underscore-delimited set of characters outlining which subset of smotifs to enumerate.
-Example: If there are 4 putative smotifs, each with 5 candidates, _0_2_3 will take the first candidate for
-smotif1, the third candidate for smotif2, the fourth candidate for smotif3, and then enumerate through
-all the candidates for smotif4, resulting in 5 structures total. For the same set, _1 will take the second
-candidate for smotif1, and enumerate all combinations for the following three smotifs, resulting in 5x5x5=125
-candidates.
-3) $havestructure - either 0 (indicate there is no solved structure for comparison) or 1 (solved structure exists
-in the input folder). If 1, the RMSD of each enumerated structure (as compared to the solved structure) will be output,
-as well as GDT_TS scores for thos structures with RMSD<10A. If the no structure option is selected (0), the RMSD
-and GDT_TS columns of the output will contain zeros.
+1. pdbcode - the 4-character name of the folder to store input and output data
+2. mot1 - an underscore-delimited set of characters outlining which subset of smotifs to enumerate.
+    Example: If there are 4 putative smotifs, each with 5 candidates, _0_2_3 will take the first candidate for
+    smotif1, the third candidate for smotif2, the fourth candidate for smotif3, and then enumerate through
+    all the candidates for smotif4, resulting in 5 structures total. For the same set, _1 will take the second
+    candidate for smotif1, and enumerate all combinations for the following three smotifs, resulting in 5x5x5=125
+    candidates.
+3. havestructure - either 0 or 1 
+                    0 indicate there is no solved structure for comparison 
+                    1 indicate solved structure exists in the input folder. 
+                    If 1, the RMSD of each enumerated structure (as compared to the solved structure) 
+                    will be output, as well as GDT_TS scores for thos structures with RMSD < 10A. 
+                    If the no structure option is selected (0), the RMSD and GDT_TS columns of the 
+                    output will contain zeros.
 
-REQUIRED FILES (all to be found in the <pdbcode> directory)
-<pdbcode>.out - file containing a list of start and end points of smotifs in the query protein, as well as secondary structure
-and loop lengths. This is one of the standard output files of the generate_shift_files.pl script.
-<pdbcode>_motifs_best.csv - file containing a list of candidates for each putative smotif. This is one of the standard output
-files of the findranks.pl script.
+REQUIRED FILES (all to be found in the "pdbcode" directory)
+   "pdbcode".out - file containing a list of start and end points of smotifs in the query protein, 
+                   as well as secondary structure and loop lengths. This is one of the standard 
+                   output files of the generate_shift_files.pl script.
+
+  "pdbcode"_motifs_best.csv - file containing a list of candidates for each putative smotif. 
+                   This is one of the standard output files of the findranks.pl script.
 
 OUTPUT (to screen)
 For each enumerated structure without excessive steric clashes (# backbone atoms within 2A < number of smotifs), tab-delimited
@@ -656,9 +663,6 @@ L<http://search.cpan.org/dist/./>
 =back
 
 
-=head1 ACKNOWLEDGEMENTS
-
-
 =head1 LICENSE AND COPYRIGHT
 
 Copyright 2015 Fiserlab Members .
