@@ -63,10 +63,11 @@ our $VERSION = '0.01';
 
 =head1 SYNOPSIS
 
-This script runs TALOS+ on the chemical shift input file in order to determine the secondary structure elements of the unknown protein
+This script runs TALOS+ on the chemical shift input file in order to determine 
+the secondary structure elements of the unknown protein
 
 INPUT ARGUMENTS:
-1) $pdb : pdb code (the chemical shift file should be in the subdirectory identified by the pdb code e.g. 1ptf/pdb1ptfshifts.dat)
+1) $pdb   :   pdb code (the chemical shift file should be in the subdirectory identified by the pdb code e.g. 1ptf/pdb1ptfshifts.dat)
 2) $chain : chain ID (default = A)
 
 INPUT FILES:
@@ -336,12 +337,17 @@ sub run_and_analyze_talos {
     if (-e "predSS.tab")    {unlink "predSS.tab"};
 }
 
-=head2
+=head2 split_ss_string
 
-	SUBROUTINE to convert a series of secondary structure types to a list of start and end points for smotifs
-	Input 1: $ss - a string of secondary structure types, where H=alpha helix and E=strand e.g. (HHHHLLLLEEEE)
-	Input 2: $startpos - residue at which first smotif begins
-	Output: Array containing Smotif definitions
+	SUBROUTINE to convert a series of secondary structure types to a list of 
+    start and end points for smotifs
+
+    Input 1: $ss - a string of secondary structure types, 
+             where H=alpha helix and E=strand e.g. (HHHHLLLLEEEE)
+	
+    Input 2: $startpos - residue at which first smotif begins
+	
+    Output  : Array containing Smotif definitions
 
 =cut
 
@@ -528,7 +534,6 @@ L<http://search.cpan.org/dist/./>
 =head1 ACKNOWLEDGEMENTS
 
 
-=head1 LICENSE AND COPYRIGHT
 
 Copyright 2015 Fiserlab Members .
 
