@@ -31,7 +31,7 @@ constructing, modifying, and evaluating the given protein structure
 
 =head2 new
 
-	Initialize a new Protein object
+Initialize a new Protein object
 
 =cut
 
@@ -69,21 +69,17 @@ sub new {
 	return bless ($self, $class);
 }
 
-
-=head2 CLASS METHODS
-
-	Methods for handling a protein
-
 =head2 last_pt
- 
-	Returns or changes the last coordinate (C-terminus) of the protein
-	test->last_pt($atom,@pt) 
-	
-        INPUTS: 
-	$atom = atom type ('CA','C','N','O','CB','H');
-	@pt (optional) = new coordinates to be assigned to the last atom
+
+Returns or changes the last coordinate (C-terminus) of the protein
+test->last_pt($atom,@pt) 
+
+INPUTS: 
+$atom = atom type ('CA','C','N','O','CB','H');
+@pt (optional) = new coordinates to be assigned to the last atom
 
 =cut
+
 sub last_pt {
 	my ($self, $atom, @pt) = @_;
 	if (@pt) {
@@ -99,6 +95,7 @@ sub last_pt {
 	test->num_res() 
 
 =cut
+
 sub num_res {
 	my ($self) = @_;
 	my @lm=$self->one_landmark(-1);
@@ -106,16 +103,15 @@ sub num_res {
 }
 
 =head2 change_pt
-    
 	Changes the coordinates of an existing atom in the protein
 	test->change_pt($atom,$index,@pt) 
-	
-        INPUTS:
-	$atom = atom type ('CA','C','N','O','CB','H');
+    INPUTS:
+	$atom  = atom type ('CA','C','N','O','CB','H');
 	$index = residue number
 	@pt new coordinates to be assigned to the atom
 
 =cut
+
 sub change_pt {
 	my ($self, $atom, $index, @pt) = @_;
 	@{$self->{$atom}[$index]}=@pt;
@@ -123,15 +119,16 @@ sub change_pt {
 
 =head2 get_coords
 	
-        Returns the coordinates (as an Nx3 array of arrays) of atoms in consecutive residues
-	test->get_coords($atom,$first,$last) 
-	
-        INPUTS:
-	$atom = atom type ('CA','C','N','O','CB','H');
-	$first = first residue index
-	$last = last residue index
+Returns the coordinates (as an Nx3 array of arrays) of atoms in consecutive residues
+test->get_coords($atom,$first,$last) 
+
+INPUTS:
+$atom = atom type ('CA','C','N','O','CB','H');
+$first = first residue index
+$last = last residue index
 
 =cut
+
 sub get_coords {
 	my ($self, $atom,$first,$last) = @_;
 	return @{$self->{$atom}}[$first..$last];
@@ -143,6 +140,7 @@ sub get_coords {
 	test->types()
 
 =cut
+
 sub types {
 	my ($self) = @_;
 	return @{$self->{type}};
@@ -158,6 +156,7 @@ sub types {
 	@newlm (optional) = array of landmarks to be assigned to the smotif
 
 =cut
+
 sub one_landmark {
 	my ($self, $index, @newlm) = @_;
 	if (@newlm) {
@@ -172,15 +171,16 @@ sub one_landmark {
 
 =head2 get_seq 
 	
-        Returns or assigns a portion of the protein sequence as a string
+    Returns or assigns a portion of the protein sequence as a string
 	test->get_seq($start,$len,$seq) 
 	
-        INPUTS:
+    INPUTS:
 	$start = start position of the sequence portion
 	$len = length of the sequence portion
 	$seq (optional) = new sequence of amino acids to assign to the given portion of the sequence
 
 =cut
+
 sub get_seq {
 	my ($self,$start,$len,$seq) = @_;
 	if ($seq) {
@@ -197,6 +197,7 @@ sub get_seq {
 	$filename = name of the output file (will be overwritten)
 
 =cut
+
 sub print_to_file {
 	my ($self, $filename) = @_;
 
@@ -262,6 +263,7 @@ sub print_to_file {
 	test->num_motifs()
 
 =cut
+
 sub num_motifs {
 	my ($self) = @_;
 	return $self->{num};
@@ -278,6 +280,7 @@ sub num_motifs {
 		2) an array with the PDB code, chain, smotif start residue, loop length, ss1 length, ss2 length, type
 
 =cut
+
 sub add_motif {
 	my ($self, @proptable) = @_;
 	my $check;
@@ -315,6 +318,7 @@ sub add_motif {
                 2) an array with the PDB code, chain, smotif start residue, loop length, ss1 length, ss2 length, type
 
 =cut
+
 sub add_motif_from_file {
 #add an smotif to an empty structure - do not call this function directly
 	my ($self, @proptable)=@_;
@@ -376,6 +380,7 @@ sub add_motif_from_file {
                 2) an array with the PDB code, chain, smotif start residue, loop length, ss1 length, ss2 length, type
 
 =cut
+
 sub add_partial_motif {
 	my ($self, @proptable)=@_;
 	#get filename and mysql info, if a simple smotif nid is given
@@ -386,7 +391,7 @@ sub add_partial_motif {
 	if (scalar(@proptable) eq 8) {
 		@idtable=@proptable;
 	} else {
-		#GeometricalCalculations::getnid(\@proptable, \@idtable);
+		# GeometricalCalculations::getnid(\@proptable, \@idtable);
 		MYSQLSmotifs::getnid(\@proptable, \@idtable);
 	}
 	my @ca=GeometricalCalculations::get_from_file(\@idtable,\@lm,'CA',\$seq);
@@ -394,14 +399,14 @@ sub add_partial_motif {
 	my @c=GeometricalCalculations::get_from_file(\@idtable,\@lm,'C',\$seq);
 	my @cb=GeometricalCalculations::get_from_file(\@idtable,\@lm,'CB',\$seq);
 	my @o=GeometricalCalculations::get_from_file(\@idtable,\@lm,'O',\$seq);
-	#generate missing C-beta atoms for glycine residues
+	# generate missing C-beta atoms for glycine residues
 	for (my $aa=0;$aa<scalar(@cb);$aa++) {
 		if ($cb[$aa]==0) {
 			$cb[$aa]=[GeometricalCalculations::findcb(\@{$ca[$aa]},\@{$c[$aa]},\@{$n[$aa]})];
 		}
 	}
 	unshift(@lm,0);
-	#align last residues of previous motif with last residues of ss1 in current motif
+	# align last residues of previous motif with last residues of ss1 in current motif
 	my @prevlm=$self->one_landmark($self->num_motifs-1);
 	my $num_to_align=$prevlm[3]-$prevlm[2];
 	if ($num_to_align>$lm[1]) {$num_to_align=$lm[1]};
@@ -411,7 +416,12 @@ sub add_partial_motif {
 	my @x=(@cap,@np,@cp);
 	my @y=(@ca[$lm[1]-$num_to_align..$lm[1]-1],@n[$lm[1]-$num_to_align..$lm[1]-1],@c[$lm[1]-$num_to_align..$lm[1]-1]);
 	my @extra=(@ca,@n,@c,@cb,@o);
-	my $rms=GeometricalCalculations::superpose(scalar(@x),\@x,\@y,\@extra);	#scalar(@x)=number of atoms, x=template to align to, y=template to align, extra=additional points 'carried along' during alignment
+    
+    # scalar(@x)=number of atoms, 
+    # x=template to align to, 
+    # y=template to align, 
+    # extra=additional points 'carried along' during alignment
+	my $rms=GeometricalCalculations::superpose(scalar(@x),\@x,\@y,\@extra);	
 	my @newca;
 	my @newn;
 	my @newc;
@@ -467,6 +477,7 @@ sub add_partial_motif {
 	option = recalculate and return (1) or just return (0)
 
 =cut
+
 sub axis {
 	my ($self, $mot, $ss, $option) = @_;
 	#option 0 = get, #option 1 = calculate
@@ -504,6 +515,7 @@ sub axis {
 	option = recalculate and return (1) or just return (0)
 
 =cut
+
 sub calc_angles {
 	my ($self, $mot, $option) = @_;
 	#option 0 = get, option 1 = calculate
@@ -530,6 +542,7 @@ sub calc_angles {
 	ang = degrees by which to change the theta angle
 
 =cut
+
 sub rotate_theta {
 	my ($self, $mot, $ang) = @_;
 	my @e1=$self->axis($mot,1,0);
@@ -575,6 +588,7 @@ sub rotate_theta {
 	ang = degrees by which to change the rho angle
 
 =cut
+
 sub rotate_rho {
 	my ($self, $mot, $ang) = @_;
 	my @e1=$self->axis($mot,1,0);
@@ -609,15 +623,15 @@ sub rotate_rho {
 
 =head2 rotate_delta
 
-	Changes the delta (hoist) angle of an smotif in a structure - all the torsional 'stress' is placed on the flanking residue
-	test->rotate_delta(mot, ang) 
+Changes the delta (hoist) angle of an smotif in a structure - all the torsional 'stress' is placed on the flanking residue
+test->rotate_delta(mot, ang) 
 
-	Inputs:
-
-	mot = smotif number
-	ang = degrees by which to change the delta angle
+Inputs:
 
+mot = smotif number
+ang = degrees by which to change the delta angle
 =cut
+
 sub rotate_delta {
 	my ($self, $mot, $ang) = @_;
 	my @e1=$self->axis($mot,1,1);
@@ -670,8 +684,8 @@ sub rotate_delta {
 
 	mot = smotif number
 	option = recalculate and return (1) or just return (0)
-
 =cut
+
 sub lvec {
 	my ($self,$mot,$option) = @_;
 	#option=0, return, option=1 calculate
@@ -707,6 +721,7 @@ sub lvec {
 	num = number of residues to shorten by
 
 =cut
+
 sub shorten {
 	my ($self,$mot,$num) = @_;
 	#motif number is where ss occurs as first structure
@@ -763,7 +778,11 @@ sub shorten {
 		my @or=$self->get_coords('o',$lmkeep[0]+$num,$total-1);
 		my $len=scalar(@car);
 		my @extra=(@car,@nr,@cr,@cbr,@or);
-		my $rms=GeometricalCalculations::superpose(scalar(@x),\@x,\@y,\@extra);	#c=number, x=template to align to, y=template to align, extra=things to align
+		# c=number, 
+        # x=template to align to, 
+        # y=template to align, 
+        # extra=things to align
+		my $rms=GeometricalCalculations::superpose(scalar(@x),\@x,\@y,\@extra);	
 		my @newca=@extra[0..$len-1];
 		my @newn=@extra[$len..2*$len-1];
 		my @newc=@extra[2*$len..3*$len-1];
@@ -824,6 +843,7 @@ sub shorten {
 	num = number of residues to extend the secondary strucure by
 
 =cut
+
 sub elongate {
 	my ($self,$mot,$num) = @_;
 	#motif number is where ss occurs as first structure
@@ -983,6 +1003,7 @@ sub elongate {
 	Note: In all cases, only the 'worst offending' set of atoms (i.e. the pair with smallest inter-atomic distance) is returned
 
 =cut
+
 sub check_ster_viols {
         my ($self,$atom,$sterdist) = @_;
         my @lm = $self->one_landmark(-1);
@@ -1011,7 +1032,8 @@ sub check_ster_viols {
                                 LOOP1:foreach my $at1 (@atomlist) {
 					if (($at1 eq 'cb') and ((substr($seq,$aa,1) eq 'G') or (substr($seq,$bb,1) eq 'G'))) {next LOOP1}	#glycine, no beta carbon
 					LOOP2:foreach my $at2 (@atomlist) {
-				                if (($at2 eq 'cb') and ((substr($seq,$aa,1) eq 'G') or (substr($seq,$bb,1) eq 'G'))) {next LOOP2}	#glycine, no beta carbon
+				                #glycine, no beta carbon
+				                if (($at2 eq 'cb') and ((substr($seq,$aa,1) eq 'G') or (substr($seq,$bb,1) eq 'G'))) {next LOOP2}
 						my $dist=GeometricalCalculations::norm2(GeometricalCalculations::vecadd(-1,@{$self->get_coords($at1,$aa,$aa)},@{$self->get_coords($at2,$bb,$bb)}));
                                                 if ($dist<$sterdist) {
                                                         if ($dist<$min[-1]) {@min=($aa,$bb,$at1,$at2,$dist);}
@@ -1033,6 +1055,7 @@ sub check_ster_viols {
 	Note: test->stat_table() has to be called before running this method
 
 =cut
+
 sub statpot {
 	my ($self) = @_;
 	my $max=10;	#inter-atomic distance cutoff
@@ -1075,6 +1098,7 @@ sub statpot {
 	NOTE: test2 must have at least as many residues as $test1
 
 =cut
+
 sub rmsd {
 	my ($self,$other)=@_;
 	my $last=$self->num_res;
@@ -1097,6 +1121,7 @@ sub rmsd {
 	NOTE: test2 must have at least as many loop residues as test1
 
 =cut
+
 sub rmsd_loops {
 	my ($self,$other)=@_;
 	my @c1;
@@ -1119,6 +1144,7 @@ sub rmsd_loops {
 	NOTE: test2 must have at least as many loop residues as test1
 
 =cut
+
 sub rmsd_loops_flanking_ss {
         my ($self,$other)=@_;
         my @c1;
@@ -1147,6 +1173,7 @@ sub rmsd_loops_flanking_ss {
 	lengths as test1, or else the function returns -1
 
 =cut
+
 sub rmsd_ss {
 	my ($self,$other,@order)=@_;
 	my @c1;
@@ -1207,6 +1234,7 @@ sub rmsd_ss {
 	rmsd=test->rmsd_anchor_order(test2,@order)
 
 =cut
+
 sub rmsd_anchor_order {
         my ($self,$other,@order)=@_;
         #gather anchor point coordinates
@@ -1254,6 +1282,7 @@ sub rmsd_anchor_order {
 	rmsd=test->rmsd_ss_order(test2,@order)
 
 =cut
+
 sub rmsd_ss_order {
 	my ($self,$other,@order)=@_;
 	#gather 
@@ -1268,6 +1297,7 @@ sub rmsd_ss_order {
 	rad=test->radius_of_gyration()
 
 =cut
+
 sub radius_of_gyration {
 	my ($self) = @_;
 	my $last=$self->num_res;
@@ -1292,6 +1322,7 @@ sub radius_of_gyration {
 	NOTE: function fails if test2 has fewer residues than test1
 
 =cut
+
 sub superpose {
 	my ($self,$other) = @_;
 	my $last=$self->num_res;
@@ -1321,6 +1352,7 @@ sub superpose {
 	rms=test->superpose_anchors(test2)
 
 =cut
+
 sub superpose_anchors {
 	my ($self,$other,@order) = @_;
 	#get coordinates of anchor points
@@ -1370,6 +1402,7 @@ sub superpose_anchors {
 	end anchor value of second ss, smotif type, ss1 length, ss2 length. 
 
 =cut
+
 sub decompose_landmarks {
 	my ($self,$outfile) = @_;
 	my @pt1;
@@ -1416,6 +1449,7 @@ sub decompose_landmarks {
 	test->lazaridis_memb()
 
 =cut
+
 sub lazaridis_memb {
 	my ($self)=@_;
 	#index order: AG|C|DEKNPQRST|FILMVWY|H|AlphaC|Nitrogen|Carbonyl|Oxygen
@@ -2212,6 +2246,8 @@ You can find documentation for this module with the perldoc command.
     perldoc Protein
 
 
+=over 4
+
 =item * RT: CPAN's request tracker (report bugs here)
 
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=.>
